@@ -1,7 +1,7 @@
 
 try:
 
-    from source.dc.data_center import DataCenter
+    from zcrmsdk.src.com.zoho.crm.api.dc.data_center import DataCenter
 
 except Exception as e:
 
@@ -22,7 +22,7 @@ class CNDataCenter(DataCenter):
         :return: A Environment class instance.
         """
 
-        return DataCenter.Environment("https://www.zohoapis.com.cn", cls().get_iam_url())
+        return DataCenter.Environment("https://www.zohoapis.com.cn", cls().get_iam_url(), cls().get_file_upload_url())
 
     @classmethod
     def SANDBOX(cls):
@@ -32,7 +32,7 @@ class CNDataCenter(DataCenter):
         :return: A Environment class instance.
         """
 
-        return DataCenter.Environment("https://sandbox.zohoapis.com.cn", cls().get_iam_url())
+        return DataCenter.Environment("https://sandbox.zohoapis.com.cn", cls().get_iam_url(), cls().get_file_upload_url())
 
     @classmethod
     def DEVELOPER(cls):
@@ -42,7 +42,7 @@ class CNDataCenter(DataCenter):
         :return: A Environment class instance.
         """
 
-        return DataCenter.Environment("https://developer.zohoapis.com.cn", cls().get_iam_url())
+        return DataCenter.Environment("https://developer.zohoapis.com.cn", cls().get_iam_url(), cls().get_file_upload_url())
 
     def get_iam_url(self):
 
@@ -52,3 +52,11 @@ class CNDataCenter(DataCenter):
         """
 
         return "https://accounts.zoho.com.cn/oauth/v2/token"
+
+    def get_file_upload_url(self):
+        """
+        The method to get File Upload URL
+        :return: A str representing the File Upload URL
+        """
+
+        return "https://content.zohoapis.com.cn"
