@@ -5,7 +5,7 @@ class Header(object):
     This class representing the HTTP header name.
     """
 
-    def __init__(self, name):
+    def __init__(self, name, class_name=None):
 
         """
         Creates an Header class instance with the specified header name.
@@ -13,3 +13,4 @@ class Header(object):
         """
 
         self.name = name
+        self.class_name = class_name
