@@ -64,14 +64,20 @@ class APIHTTPConnector(object):
             response = requests.get(self.url, headers=self.headers, params=self.parameters, allow_redirects=False)
 
         elif self.request_method == Constants.REQUEST_METHOD_PUT:
-            data = convert_instance.append_to_request(self, self.request_body)
+            data = None
+            if convert_instance is not None:
+                data = convert_instance.append_to_request(self, self.request_body)
+
             response = requests.put(self.url, data=data, params=self.parameters, headers=self.headers, allow_redirects=False)
 
         elif self.request_method == Constants.REQUEST_METHOD_POST:
-            data = convert_instance.append_to_request(self, self.request_body)
+            data = None
+            if convert_instance is not None:
+                data = convert_instance.append_to_request(self, self.request_body)
 
             if self.file is False:
                 response = requests.post(self.url, data=data, params=self.parameters, headers=self.headers, allow_redirects=False)
+                
             else:
                 response = requests.post(self.url, files=data, headers=self.headers, allow_redirects=False, data={})
 
