@@ -1,53 +1,34 @@
 
 try:
-
-    from .api_http_connector import APIHTTPConnector
-
-    from .json_converter import JSONConverter
-
-    from .xml_converter import XMLConverter
-
-    from .form_data_converter import FormDataConverter
-
-    from .downloader import Downloader
-
-    from .constants import Constants
-
     import json
-
     import platform
-
-    from .api_response import APIResponse
-
-    from ..header_map import HeaderMap
-
-    from ..header import Header
-
-    from ..param_map import ParameterMap
-
-    from ..param import Param
+    import urllib
+    from zcrmsdk.src.com.zoho.crm.api.util.api_http_connector import APIHTTPConnector
+    from zcrmsdk.src.com.zoho.crm.api.util.json_converter import JSONConverter
+    from zcrmsdk.src.com.zoho.crm.api.util.xml_converter import XMLConverter
+    from zcrmsdk.src.com.zoho.crm.api.util.form_data_converter import FormDataConverter
+    from zcrmsdk.src.com.zoho.crm.api.util.downloader import Downloader
+    from zcrmsdk.src.com.zoho.crm.api.util.constants import Constants
+    from zcrmsdk.src.com.zoho.crm.api.util.api_response import APIResponse
+    from zcrmsdk.src.com.zoho.crm.api.header_map import HeaderMap
+    from zcrmsdk.src.com.zoho.crm.api.header import Header
+    from zcrmsdk.src.com.zoho.crm.api.parameter_map import ParameterMap
+    from zcrmsdk.src.com.zoho.crm.api.param import Param
+    from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 except Exception:
-
-    from .api_http_connector import APIHTTPConnector
-
-    from .json_converter import JSONConverter
-
-    from .constants import Constants
-
     import json
-
     import platform
-
+    import urllib
+    from .api_http_connector import APIHTTPConnector
+    from .json_converter import JSONConverter
+    from .constants import Constants
     from .api_response import APIResponse
-
     from ..header_map import HeaderMap
-
     from ..header import Header
-
-    from ..param_map import ParameterMap
-
+    from ..parameter_map import ParameterMap
     from ..param import Param
+    from zcrmsdk.src.com.zoho.api.exception import SDKException
 
 
 class CommonAPIHandler(object):
@@ -62,17 +43,11 @@ class CommonAPIHandler(object):
     def __init__(self):
 
         self.api_path = None
-
         self.header = HeaderMap()
-
         self.param = ParameterMap()
-
         self.request = None
-
         self.http_method = None
-
         self.module_api_name = None
-
         self.content_type = None
 
     def add_param(self, param_name, param_value):
@@ -83,6 +58,9 @@ class CommonAPIHandler(object):
         :param param_value: A object containing the API request parameter value.
         """
 
+        if self.param is None:
+            self.param = ParameterMap()
+
         self.param.add(Param(param_name), param_value)
 
     def add_header(self, header_name, header_value):
@@ -93,6 +71,9 @@ class CommonAPIHandler(object):
         :param header_value: A object containing the API request header value.
         """
 
+        if self.header is None:
+            self.header = HeaderMap()
+
         self.header.add(Header(header_name), header_value)
 
     def api_call(self, class_name, encode_type):
@@ -103,57 +84,76 @@ class CommonAPIHandler(object):
         :param encode_type: A str containing the expected API response content type.
         :return:  A APIResponse representing the Zoho CRM API response instance or None.
         """
-
-        import zcrmsdk.src.com.zoho.crm.api.initializer as Init
+        try:
+            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+        except Exception:
+            from ..initializer import Initializer
 
         connector = APIHTTPConnector()
+        self.set_api_url(connector)
+        connector.request_method = self.http_method
+        connector.content_type = self.content_type
 
-        connector.url = Init.Initializer.get_initializer().environment.url + self.api_path
-
-        connector.req_method = self.http_method
-
-        if len(self.header.header_map) > 0:
-
+        if self.header is not None and len(self.header.header_map) > 0:
             connector.headers = self.header.header_map
 
-        if len(self.param.parameter_map) > 0:
-
-            connector.params = self.param.parameter_map
-
-        Init.Initializer.get_initializer().token.authenticate(connector)
+        if self.param is not None and len(self.param.parameter_map) > 0:
+            connector.parameters = self.param.parameter_map
 
+        Initializer.get_initializer().token.authenticate(connector)
         convert_instance = None
 
-        if self.http_method == Constants.REQUEST_METHOD_POST or self.http_method == Constants.REQUEST_METHOD_PUT:
-
+        if self.content_type is not None and (self.http_method == Constants.REQUEST_METHOD_POST or self.http_method == Constants.REQUEST_METHOD_PUT):
             convert_instance = self.get_converter_class_instance(self.content_type)
-
             request = convert_instance.form_request(self.request, self.request.__class__.__module__, 1)
-
-            connector.req_body = request
+            connector.request_body = request
 
         connector.headers[Constants.ZOHO_SDK] = platform.system() + "/" + platform.release() + " python/" + platform.python_version() + ":" + Constants.SDK_VERSION
-
         response = connector.fire_request(convert_instance)
-
         status_code = response.status_code
-
         headers = response.headers
-
         content_type = response.headers[Constants.CONTENT_TYPE]
 
         if ";" in content_type:
-
             content_type = content_type.rpartition(";")[0]
 
         convert_instance = self.get_converter_class_instance(content_type)
-
-        class_name = str(class_name).replace("src.", "")
-
+        class_name = str(class_name)
         return_object = convert_instance.get_wrapped_response(response, class_name)
 
         return APIResponse(headers, status_code, return_object)
 
+    def set_api_url(self, connector):
+        try:
+            from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
+        except Exception:
+            from ..initializer import Initializer
+
+        api_path = ''
+
+        if 'http' in self.api_path:
+            if 'content.zohoapis.com' in self.api_path:
+                api_path = Initializer.get_initializer().environment.file_upload_url
+
+                try:
+                    url_parse = urllib.parse.urlparse(self.api_path)
+                    path = url_parse[2]
+                except Exception as ex:
+                    CommonAPIHandler.logger.info("Exception in URL " + str(ex))
+                    raise SDKException(None, None, None, ex)
+
+                api_path = api_path + path
+            else:
+                if str(self.api_path)[:1].__eq__('/'):
+                    self.api_path = self.api_path[1:]
+
+                api_path = api_path + self.api_path
+        else:
+            api_path = Initializer.get_initializer().environment.url
+            api_path = api_path + self.api_path
+
+        connector.url = api_path
+
     def get_converter_class_instance(self, encode_type):
 
         """
