@@ -1,4 +1,3 @@
-
 try:
     import importlib
     import logging
@@ -20,7 +19,6 @@ except Exception:
 
 
 class FormDataConverter(Converter):
-
     """
     This class to process the upload file and stream.
     """
@@ -58,10 +56,11 @@ class FormDataConverter(Converter):
         class_detail = dict(Initializer.json_details[str(pack)])
         request = dict()
 
-        for member_name in class_detail:
-            member_detail = class_detail[member_name]
+        for member_name, member_detail in class_detail.items():
+            modification = None
 
-            if (Constants.READ_ONLY in member_detail and bool(member_detail[Constants.READ_ONLY])) or Constants.NAME not in member_detail:
+            if (Constants.READ_ONLY in member_detail and bool(
+                    member_detail[Constants.READ_ONLY])) or Constants.NAME not in member_detail:
                 continue
 
             try:
@@ -75,12 +74,14 @@ class FormDataConverter(Converter):
                                    Constants.MANDATORY_KEY_MISSING_ERROR + member_name)
 
             field_value = getattr(request_instance, self.construct_private_member(class_name=class_name, member_name=member_name))
-            if modification is not None:
-                try:
-                    getattr(request_instance, Constants.SET_KEY_MODIFIED)(member_name, 0)
-                except Exception as e:
-                    FormDataConverter.logger.info(Constants.EXCEPTION_SET_KEY_MODIFIED + e.__str__())
 
+            if modification is not None and modification != 0 and self.value_checker(
+                    class_name=class_name,
+                    member_name=member_name,
+                    key_details=member_detail,
+                    value=field_value,
+                    unique_values_map=self.unique_dict,
+                    instance_number=instance_number) is True:
                 key_name = member_detail.get(Constants.NAME)
                 data_type = member_detail.get(Constants.TYPE)
 
