@@ -92,7 +92,7 @@ class JSONConverter(Converter):
         except Exception:
             from ..initializer import Initializer
 
-        request_json, module_detail, reset_modified = {}, {}, {}
+        request_json, module_detail = {}, {}
         module_api_name = self.common_api_handler.module_api_name
         class_name = record_instance.__class__.__name__
 
@@ -154,11 +154,8 @@ class JSONConverter(Converter):
             if modification is None or modification == 0:
                 continue
 
-            reset_modified[key_name] = 0
             request_json[key_name] = json_value
 
-        setattr(record_instance, self.construct_private_member(class_name, Constants.KEY_MODIFIED), reset_modified)
-
         return request_json
 
     def is_not_record_request(self, request_instance, class_name, class_detail, instance_number):
@@ -170,6 +167,8 @@ class JSONConverter(Converter):
         request_json = {}
 
         for member_name, member_detail in class_detail.items():
+            modification = None
+
             if Constants.READ_ONLY in member_name or (Constants.NAME not in member_detail):
                 continue
 
@@ -194,21 +193,16 @@ class JSONConverter(Converter):
                                                                                      instance_number=instance_number) is True:
                 key_name = member_detail.get(Constants.NAME)
 
-                try:
-                    getattr(request_instance, Constants.SET_KEY_MODIFIED)(key_name, 0)
-                except Exception as e:
-                    JSONConverter.logger.info(Constants.EXCEPTION_IS_KEY_MODIFIED + e.__str__())
-
                 if isinstance(request_instance, FileDetails):
                     if key_name.lower() == Constants.ATTACHMENT_ID.lower():
                         request_json[key_name.lower()] = field_value
+
                     elif key_name.lower() == Constants.FILE_ID.lower():
                         request_json[key_name.lower()] = field_value
+
                     else:
-                        if field_value is None:
-                            request_json[key_name.lower()] = None
-                        else:
-                            request_json[key_name.lower()] = field_value
+                        request_json[key_name.lower()] = None if field_value is None else field_value
+
                 else:
                     request_json[key_name] = self.set_data(member_detail, field_value)
 
@@ -399,8 +393,7 @@ class JSONConverter(Converter):
 
         for each_class in class_list:
             if Constants.RECORD_TYPE in str(each_class):
-                record_instance = JSONConverter.__get_instance_from_name(Constants.RECORD_NAMESPACE)
-                class_name = Constants.RECORD_NAMESPACE.rpartition('.')[-1]
+                class_name = Constants.RECORD_CLASS_NAME
                 break
 
         key_values = {}
