@@ -8,26 +8,22 @@ class StreamWrapper(object):
     This class handles the file stream and name.
     """
 
-    def __init__(self, file_path, name=None, stream=None):
+    def __init__(self, name=None, stream=None, file_path=None):
 
         """
         Creates a StreamWrapper class instance with the specified parameters.
-        :param file_path: A str containing the file path.
         :param name: A str containing the file name.
         :param stream: A stream containing the file stream.
+        :param file_path: A str containing the absolute file path.
         """
 
         if file_path is not None:
-
-            self.name = os.path.basename(file_path)
-
-            self.stream = open(file_path, 'rb')
+            self.__name = os.path.basename(file_path)
+            self.__stream = open(file_path, 'rb')
 
         else:
-
-            self.name = name
-
-            self.stream = stream
+            self.__name = name
+            self.__stream = stream
 
     def get_name(self):
 
@@ -36,7 +32,7 @@ class StreamWrapper(object):
         :return: A str representing the file name.
         """
 
-        return self.name
+        return self.__name
 
     def get_stream(self):
 
@@ -45,4 +41,4 @@ class StreamWrapper(object):
         :return: A stream representing the file input stream.
         """
 
-        return self.stream
+        return self.__stream
