@@ -468,6 +468,13 @@ class Utility(object):
 
             return
 
+        elif key_name.lower() == Constants.COMMENTS.lower() and module_api_name.lower() == Constants.SOLUTIONS.lower():
+            field_detail[Constants.NAME] = key_name
+            field_detail[Constants.TYPE] = Constants.LIST_NAMESPACE
+            field_detail[Constants.STRUCTURE_NAME] = Constants.COMMENT_NAMESPACE
+
+            return
+
         elif key_name.lower() == Constants.LAYOUT.lower():
             field_detail[Constants.NAME] = key_name
             field_detail[Constants.TYPE] = Constants.LAYOUT_NAMESPACE
